@@ -5,7 +5,6 @@ import numpy as np
 import os
 from configparser import ConfigParser
 import random
-import tqdm
 
 try:
     from sorn.utils import Initializer
@@ -817,6 +816,7 @@ class Simulator_(Sorn):
         matrices: dict = None,
         time_steps: int = None,
         noise: bool = True,
+        freeze: list = None,
         **kwargs
     ):
         """Simulation/Plasticity phase
@@ -832,6 +832,8 @@ class Simulator_(Sorn):
 
             noise (bool, optional): If True, noise will be added. Defaults to True.
 
+            freeze (list, optional): List of synaptic plasticity mechanisms which will be turned off during simulation. Defaults to None.
+
         Returns:
             plastic_matrices (dict): Network states, connections and threshold matrices
 
@@ -851,6 +853,7 @@ class Simulator_(Sorn):
         Sorn._time_steps = time_steps
         self.phase = phase
         self.matrices = matrices
+        self.freeze = freeze
 
         kwargs_ = [
             "_ne",
@@ -890,7 +893,7 @@ class Simulator_(Sorn):
         frac_pos_active_conn = []
 
         # To get the last activation status of Exc and Inh neurons
-        for i in tqdm.tqdm(range(self.time_steps)):
+        for i in range(self.time_steps):
 
             if noise:
                 white_noise_e = Initializer.white_gaussian_noise(
@@ -904,7 +907,7 @@ class Simulator_(Sorn):
 
             network_state = NetworkState(
                 inputs[:, i]
-            )  # Feed input and initialize network state
+            )
 
             # Buffers to get the resulting x and y vectors at the current time step and update the master matrix
             x_buffer, y_buffer = np.zeros(
@@ -952,25 +955,28 @@ class Simulator_(Sorn):
             plasticity = Plasticity()
 
             # STDP
-            Wee_t = plasticity.stdp(
-                Wee[i], x_buffer, cutoff_weights=(0.0, 1.0))
+            if 'stdp' not in self.freeze:
+                Wee_t = plasticity.stdp(
+                    Wee[i], x_buffer, cutoff_weights=(0.0, 1.0))
 
             # Intrinsic plasticity
-            Te_t = plasticity.ip(Te[i], x_buffer)
+            if 'ip' not in self.freeze:
+                Te_t = plasticity.ip(Te[i], x_buffer)
 
             # Structural plasticity
-            Wee_t = plasticity.structural_plasticity(Wee_t)
+            if 'sp' not in freeze:
+                Wee_t = plasticity.structural_plasticity(Wee_t)
 
             # iSTDP
-            Wei_t = plasticity.istdp(
-                Wei[i], x_buffer, y_buffer, cutoff_weights=(0.0, 1.0)
-            )
+            if 'istdp' not in freeze:
+                Wei_t = plasticity.istdp(
+                    Wei[i], x_buffer, y_buffer, cutoff_weights=(0.0, 1.0)
+                )
 
             # Synaptic scaling Wee
-            Wee_t = Plasticity().ss(Wee_t)
-
-            # Synaptic scaling Wei
-            Wei_t = Plasticity().ss(Wei_t)
+            if 'ss' not in self.freeze:
+                Wee_t = Plasticity().ss(Wee_t)
+                Wei_t = Plasticity().ss(Wei_t)
 
             # Assign the matrices to the matrix collections
             matrix_collection.weight_matrix(Wee_t, Wei_t, Wie[i], i)
@@ -1008,6 +1014,8 @@ class Trainer_(Sorn):
 
         noise (bool, optional): If True, noise will be added. Defaults to True.
 
+        freeze (list, optional): List of synaptic plasticity mechanisms which will be turned off during simulation. Defaults to None.
+
     Returns:
         plastic_matrices (dict): Network states, connections and threshold matrices
 
@@ -1030,6 +1038,7 @@ class Trainer_(Sorn):
         matrices: dict = None,
         time_steps: int = None,
         noise: bool = True,
+        freeze: list = None,
         **kwargs
     ):
         """Train the network with the fresh or pretrained network matrices and external stimuli
@@ -1090,7 +1099,7 @@ class Trainer_(Sorn):
         self.time_steps = time_steps
         Sorn._time_steps = time_steps
         self.inputs = np.asarray(inputs)
-
+        self.freeze = freeze
         # Collect the network activity at all time steps
         X_all = [0] * self.time_steps
         Y_all = [0] * self.time_steps
@@ -1160,25 +1169,30 @@ class Trainer_(Sorn):
                 plasticity = Plasticity()
 
                 # STDP
-                Wee_t = plasticity.stdp(
-                    Wee[i], x_buffer, cutoff_weights=(0.0, 1.0))
+                if 'stdp' not in self.freeze:
+                    Wee_t = plasticity.stdp(
+                        Wee[i], x_buffer, cutoff_weights=(0.0, 1.0))
 
                 # Intrinsic plasticity
-                Te_t = plasticity.ip(Te[i], x_buffer)
+                if 'ip' not in self.freeze:
+                    Te_t = plasticity.ip(Te[i], x_buffer)
 
                 # Structural plasticity
-                Wee_t = plasticity.structural_plasticity(Wee_t)
+                if 'sp' not in self.freeze:
+                    Wee_t = plasticity.structural_plasticity(Wee_t)
 
                 # iSTDP
-                Wei_t = plasticity.istdp(
-                    Wei[i], x_buffer, y_buffer, cutoff_weights=(0.0, 1.0)
-                )
+                if 'istdp' not in self.freeze:
+                    Wei_t = plasticity.istdp(
+                        Wei[i], x_buffer, y_buffer, cutoff_weights=(0.0, 1.0)
+                    )
 
                 # Synaptic scaling Wee
-                Wee_t = Plasticity().ss(Wee_t)
+                if 'sc' not in self.freeze:
+                    Wee_t = Plasticity().ss(Wee_t)
 
-                # Synaptic scaling Wei
-                Wei_t = Plasticity().ss(Wei_t)
+                    # Synaptic scaling Wei
+                    Wei_t = Plasticity().ss(Wei_t)
             else:
                 Wee_t, Wei_t, Te_t = Wee[i], Wei[i], Te[i]
 
